//=============================================================================
// Change_LimitBreak_MZ.js
//   Last update: 2024/09/22
//=============================================================================
// 更新っぽいもの
// 
// 2024/09/15 [v0.1.0]
// 初版
// 
// 2024/09/22 [v0.1.1]
// 一部のパラメータには入力値の上限と下限を設定
// スクリプトのヘルプを更新

/*:
 * @target MZ
 * 
 * @plugindesc
 * [v0.1.1] Change!! Limmit Break MZ.
 * 
 * @author Diamond
 *
 * @param Max Level
 * @text ????
 * @default 100
 * @type number
 * @min 1
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 * 
 * @param Max Gold
 * @text ????
 * @default 999999999
 * @type number
 * @min 1
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 *
 * @param Item Max Hold
 * @text ????
 * @default 125
 * @type number
 * @min 1
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 *
 * @param Max Battle Members
 * @text ????
 * @default 4
 * @type number
 * @min 1
 * @max 5
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 *
 * @param Battler Max TP
 * @text ????
 * @default 120
 * @type number
 * @min 1
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 *
 * @param Max Save
 * @text ????
 * @default 25
 * @type number
 * @min 4
 * @desc
 * English is not supported.
 * Please Use Japanese!!
 *
 * @help
 * Diamond use ruby, not use Java Script!!
 * Please use Ruby!! and RPG Tkool XP/VX/VX Ace.
 * 
 * @url https://diamond.iza-yoi.net/
 */

/*:ja
 * @target MZ
 * 
 * @plugindesc
 * [v0.1.1] 真（チェンジ！！）限界突破 MZ
 * 
 * @author 貪藻矢射妥←
 *
 * @param Max Level
 * @text 最大レベル
 * @default 100
 * @type number
 * @min 1
 * @desc レベル上限を指定します。
 *
 * @param Max Gold
 * @text ゴールド最大値
 * @default 999999999
 * @type number
 * @min 1
 * @desc 所持金の上限を指定します。
 *
 * @param Item Max Hold
 * @text アイテム所持数最大値
 * @default 125
 * @type number
 * @min 1
 * @desc アイテム所持数の上限を指定します。
 *
 * @param Max Battle Members
 * @text パーティーメンバー最大値
 * @default 4
 * @type number
 * @min 1
 * @max 5
 * @desc パーティーメンバー上限を指定します。
 *
 * @param Battler Max TP
 * @text 最大TP
 * @default 120
 * @type number
 * @min 1
 * @desc バトラーのMaxTPを指定します。
 *
 * @param Max Save
 * @text セーブファイル最大値
 * @default 25
 * @type number
 * @min 4
 * @desc セーブファイル上限を指定します。
 *
 * @help
 * ゲーム内の各種上限値を設定し直します。
 *
 * ※注意事項※
 * 1) Lv上限を100以上に変更した後、
 * RPGツクールXP/VX/VXA RGSS ツクールMV/MZパラメータジェネレーター
 * で作成したパラメータリストを
 * data/Classes.json の 
 * "params":[[hogehoge]] の [[hogehoge]]の部分と差し替えてください。
 * あるいはRubyツールのパラメータジェネレーターでClasses.jsonを更新してください。
 * そうしないとLv100以降バグります。
 * 
 * 2) パーティーメンバー最大値を5以上に変更した場合、
 * バトルで5人目が表示されません。
 * Java Scriptでそこまでして表示改造する気力がなかったので
 * パーティーメンバー最大値を5人以上にする場合は
 * 別途5人パーティーできちんと表示できるプラグインを導入してください。
 * 
 * Java ScriptよりもRubyを使いたい！ by 貪藻矢射妥←
 * 
 * @url https://diamond.iza-yoi.net/
 */

var OuterFlgs = OuterFlgs || {};

(() => {

OuterFlgs.imported = OuterFlgs.imported || {};
OuterFlgs.imported['LimitBreak'] = true;

var pluginParams = PluginManager.parameters('Change_LimitBreak_MZ');
var changeLimitBreakMaxLevel         = Number(pluginParams['Max Level'] || 100);
var changeLimitBreakMaxGold          = Number(pluginParams['Max Gold'] || 999999999);
var changeLimitBreakItemMaxHold      = Number(pluginParams['Item Max Hold'] || 125);
var changeLimitBreakMaxBattleMembers = Number(pluginParams['Max Battle Members'] || 4);
var changeLimitBreakBattlerMtp       = Number(pluginParams['Battler Max TP'] || 120);
var changeLimitBreakMaxSave          = Number(pluginParams['Max Save'] || 25);

Scene_Battle.BATTLE_COMMAND_WINDOW_WIDTH = 192;
Scene_Battle.PARTY_COMMAND_WINDOW_HEIGHT = 120;

//-----------------------------------------------------------------------------
// DataManager

DataManager.maxSavefiles = function() {
    return changeLimitBreakMaxSave;
};

//-----------------------------------------------------------------------------
// Game_BattlerBase

Game_BattlerBase.prototype.maxTp = function() {
    return changeLimitBreakBattlerMtp;
};

//-----------------------------------------------------------------------------
// Game_Actor

Game_Actor.prototype.maxLevel = function() {
    return changeLimitBreakMaxLevel;
};

//-----------------------------------------------------------------------------
// Game_Party

Game_Party.prototype.maxBattleMembers = function() {
    return changeLimitBreakMaxBattleMembers;
};

Game_Party.prototype.maxGold = function() {
    return changeLimitBreakMaxGold;
};

Game_Party.prototype.maxItems = function(/*item*/) {
    return changeLimitBreakItemMaxHold;
};

//-----------------------------------------------------------------------------
// Scene_Battle

Scene_Battle.prototype.partyCommandWindowRect = function() {
    const ww = Scene_Battle.BATTLE_COMMAND_WINDOW_WIDTH;
    const wh = Scene_Battle.PARTY_COMMAND_WINDOW_HEIGHT;
    const wx = this.isRightInputMode() ? Graphics.boxWidth - ww : 0;
    const wy = Graphics.boxHeight - wh;
    return new Rectangle(wx, wy, ww, wh);
};


//パーティーメンバーが5人の場合を考えようと思ったけどうまくいかなかった。


/* Scene_Battle.prototype.createActorCommandWindow = function() {
    const rect = this.actorCommandWindowRect(this._actorCommandWindow.index());
    const commandWindow = new Window_ActorCommand(rect);
    commandWindow.y = Graphics.boxHeight - commandWindow.height;
    commandWindow.setHandler("attack", this.commandAttack.bind(this));
    commandWindow.setHandler("skill", this.commandSkill.bind(this));
    commandWindow.setHandler("guard", this.commandGuard.bind(this));
    commandWindow.setHandler("item", this.commandItem.bind(this));
    commandWindow.setHandler("cancel", this.commandCancel.bind(this));
    this.addWindow(commandWindow);
    this._actorCommandWindow = commandWindow;
};

Scene_Battle.prototype.actorCommandWindowRect = function() {
    const ww = Scene_Battle.BATTLE_COMMAND_WINDOW_WIDTH;
    const wh = this.windowAreaHeight();
    //const wx = this.isRightInputMode() ? Graphics.boxWidth - ww : 0;
    const wx = 154;
    //const wy = Graphics.boxHeight - wh;
    const wy = -100;
    return new Rectangle(wx, wy, ww, wh);
}; */



})();
